#!/usr/bin/env python

from distutils.core import setup



setup(name='groove_waveform',
      version='1.0',
      description='waveform generation using libgroove',
      author='Basit Raza',
      author_email='basit.raza11@gmail.com',
      url='https://github.com/geek96/waveform-python',
      package_dir={'waveform': 'waveform'}   
  )
